/* gestalt.h: The list of gestalt selectors for Glulxe.
    Designed by Andrew Plotkin <erkyrath@eblong.com>
    http://eblong.com/zarf/glulx/index.html
*/

#ifndef _GESTALT_H
#define _GESTALT_H

#define gestulx_GlulxVersion (0)
#define gestulx_TerpVersion (1)
#define gestulx_ResizeMem (2)
#define gestulx_Undo (3)
#define gestulx_IOSystem (4)
#define gestulx_Unicode (5)
#define gestulx_MemCopy (6)
#define gestulx_MAlloc (7)
#define gestulx_MAllocHeap (8)
#define gestulx_Acceleration (9)
#define gestulx_AccelFunc (10)
#define gestulx_Float (11)
#define gestulx_ExtUndo (12)
#define gestulx_Double (13)

#endif /* _GESTALT_H */

